@@ -1,14 +1,13 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "copilot" "0.4.0"
-  "An Emacs plugin for GitHub Copilot."
-  '((emacs         "27.2")
-    (editorconfig  "0.8.2")
-    (jsonrpc       "1.0.14")
-    (compat        "30")
-    (track-changes "1.4"))
+(define-package "copilot" "20250916.500"
+  "An unofficial Copilot plugin."
+  '((emacs        "27.2")
+    (editorconfig "0.8.2")
+    (jsonrpc      "1.0.14")
+    (f            "0.20.0"))
   :url "https://github.com/copilot-emacs/copilot.el"
-  :commit "7904f13d52e8dcda3af67142c42fa7c8345ba6fe"
-  :revdesc "7904f13d52e8"
+  :commit "c42c18e346e1ff8399eb30d40527e593f614e4d3"
+  :revdesc "c42c18e346e1"
   :keywords '("convenience" "copilot")
   :authors '(("zerol" . "z@zerol.me"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")
